# Authors and Contributors

This project is developed and maintained by the nesalia-inc team and the open-source community.

## Maintainers

- **nesalia-inc** - Project lead and maintainer

## Contributors

Thank you to all the people who have contributed to this project!

<!-- If you want to display contributor avatars, you can use:
[![Contributors](https://contrib.rocks/image?repo=nesalia-inc/better-py)](https://github.com/nesalia-inc/better-py/graphs/contributors)

-->

## How to Contribute

We welcome contributions from everyone! Please see [CONTRIBUTING.md](CONTRIBUTING.md) for details on how to get started.

## Acknowledgments

The following projects and their authors have inspired better-py:

- [toolz](https://github.com/pytoolz/toolz) - Functional iteration tools
- [returns](https://github.com/dry-python/returns) - Modern functional programming in Python
- [cats](https://github.com/typelevel/cats) - Functional programming in Scala
- [scalaz](https://github.com/scalaz/scalaz) - Type-level functional programming
- [PyMonad](https://github.com/jasondelaat/pymonad) - Monads in Python
- [OCharge](https://github.com/malthe/ocarge) - Collection operations

---

**Add your name here by contributing!** See [CONTRIBUTING.md](CONTRIBUTING.md) for details.
